@@ -212,8 +212,7 @@ them.
 
 You can use ``--destination`` or ``-d`` flag to set the location where the new
 data is copied to. This location be will under the dataset's data directory and
-will be created if does not exists. You will get an error message if the
-destination exists and is a file.
+will be created if does not exists.
 
 .. code-block:: console
 
@@ -510,6 +509,7 @@ from pathlib import Path
 
 import click
 
+import renku.cli.utils.color as color
 from renku.cli.utils.callback import ClickCallback
 from renku.core.commands.format.dataset_files import DATASET_FILES_COLUMNS, DATASET_FILES_FORMATS
 from renku.core.commands.format.dataset_tags import DATASET_TAGS_FORMATS
@@ -517,10 +517,10 @@ from renku.core.commands.format.datasets import DATASETS_COLUMNS, DATASETS_FORMA
 
 
 def _complete_datasets(ctx, param, incomplete):
-    from renku.core.commands.dataset import search_datasets
+    from renku.core.commands.dataset import search_datasets_command
 
     try:
-        result = search_datasets().build().execute(name=incomplete)
+        result = search_datasets_command().build().execute(name=incomplete)
         return result.output
     except Exception:
         return []
@@ -544,10 +544,14 @@ def dataset():
 )
 def list_dataset(format, columns):
     """List datasets."""
-    from renku.core.commands.dataset import list_datasets
+    from renku.core.commands.dataset import list_datasets_command
 
-    result = list_datasets().lock_dataset().build().execute(format=format, columns=columns)
-    click.echo(result.output)
+    if format not in DATASETS_FORMATS:
+        raise click.BadParameter(f"format '{format}' not supported")
+
+    result = list_datasets_command().lock_dataset().build().execute()
+
+    click.echo(DATASETS_FORMATS[format](result.output, columns=columns))
 
 
 @dataset.command()
@@ -572,7 +576,8 @@ def list_dataset(format, columns):
 @click.option("-k", "--keyword", default=None, multiple=True, type=click.STRING, help="List of keywords.")
 def create(name, title, description, creators, metadata, keyword):
     """Create an empty dataset in the current repo."""
-    from renku.core.commands.dataset import create_dataset
+    from renku.core.commands.dataset import create_dataset_command
+    from renku.core.utils.metadata import construct_creators
 
     communicator = ClickCallback()
     creators = creators or ()
@@ -582,8 +587,11 @@ def create(name, title, description, creators, metadata, keyword):
     if metadata:
         custom_metadata = json.loads(Path(metadata).read_text())
 
+    if creators:
+        creators, _ = construct_creators(creators)
+
     result = (
-        create_dataset()
+        create_dataset_command()
         .with_communicator(communicator)
         .build()
         .execute(
@@ -599,7 +607,7 @@ def create(name, title, description, creators, metadata, keyword):
     new_dataset = result.output
 
     click.echo(f'Use the name "{new_dataset.name}" to refer to this dataset.')
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command()
@@ -624,18 +632,23 @@ def create(name, title, description, creators, metadata, keyword):
 @click.option("-k", "--keyword", default=None, multiple=True, type=click.STRING, help="List of keywords or tags.")
 def edit(name, title, description, creators, metadata, keyword):
     """Edit dataset metadata."""
-    from renku.core.commands.dataset import edit_dataset
+    from renku.core.commands.dataset import edit_dataset_command
+    from renku.core.utils.metadata import construct_creators
 
     creators = creators or ()
     keywords = keyword or ()
 
     custom_metadata = None
+    no_email_warnings = False
+
+    if creators:
+        creators, no_email_warnings = construct_creators(creators, ignore_email=True)
 
     if metadata:
         custom_metadata = json.loads(Path(metadata).read_text())
 
-    result = (
-        edit_dataset()
+    updated = (
+        edit_dataset_command()
         .build()
         .execute(
             name=name,
@@ -646,9 +659,7 @@ def edit(name, title, description, creators, metadata, keyword):
             skip_image_update=True,
             custom_metadata=custom_metadata,
         )
-    )
-
-    updated, no_email_warnings = result.output
+    ).output
 
     if not updated:
         click.echo(
@@ -668,14 +679,14 @@ def edit(name, title, description, creators, metadata, keyword):
 @click.argument("name", shell_complete=_complete_datasets)
 def show(name):
     """Show metadata of a dataset."""
-    from renku.core.commands.dataset import show_dataset
+    from renku.core.commands.dataset import show_dataset_command
     from renku.core.utils.os import print_markdown
 
-    result = show_dataset().build().execute(name=name)
+    result = show_dataset_command().build().execute(name=name)
     ds = result.output
 
-    click.echo(click.style("Name: ", bold=True, fg="magenta") + click.style(ds["name"], bold=True))
-    click.echo(click.style("Created: ", bold=True, fg="magenta") + (ds.get("created_at", "") or ""))
+    click.echo(click.style("Name: ", bold=True, fg=color.MAGENTA) + click.style(ds["name"], bold=True))
+    click.echo(click.style("Created: ", bold=True, fg=color.MAGENTA) + (ds.get("created_at", "") or ""))
 
     creators = []
     for creator in ds.get("creators", []):
@@ -684,20 +695,20 @@ def show(name):
         else:
             creators.append(f"{creator['name']} <{creator['email']}>")
 
-    click.echo(click.style("Creator(s): ", bold=True, fg="magenta") + ", ".join(creators))
+    click.echo(click.style("Creator(s): ", bold=True, fg=color.MAGENTA) + ", ".join(creators))
     if ds["keywords"]:
-        click.echo(click.style("Keywords: ", bold=True, fg="magenta") + ", ".join(ds.get("keywords", "")))
+        click.echo(click.style("Keywords: ", bold=True, fg=color.MAGENTA) + ", ".join(ds.get("keywords", "")))
 
     if ds["version"]:
-        click.echo(click.style("Version: ", bold=True, fg="magenta") + ds.get("version", ""))
+        click.echo(click.style("Version: ", bold=True, fg=color.MAGENTA) + ds.get("version", ""))
 
     if ds["annotations"]:
-        click.echo(click.style("Annotations: ", bold=True, fg="magenta"))
+        click.echo(click.style("Annotations: ", bold=True, fg=color.MAGENTA))
         click.echo(json.dumps(ds.get("annotations", ""), indent=2))
 
-    click.echo(click.style("Title: ", bold=True, fg="magenta") + click.style(ds.get("title", ""), bold=True))
+    click.echo(click.style("Title: ", bold=True, fg=color.MAGENTA) + click.style(ds.get("title", ""), bold=True))
 
-    click.echo(click.style("Description: ", bold=True, fg="magenta"))
+    click.echo(click.style("Description: ", bold=True, fg=color.MAGENTA))
     print_markdown(ds.get("description", "") or "")
 
 
@@ -717,12 +728,12 @@ def show(name):
 @click.option("--ref", default=None, help="Add files from a specific commit/tag/branch.")
 def add(name, urls, external, force, overwrite, create, sources, destination, ref):
     """Add data to a dataset."""
-    from renku.core.commands.dataset import add_to_dataset
+    from renku.core.commands.dataset import add_to_dataset_command
 
     communicator = ClickCallback()
-    add_to_dataset().with_communicator(communicator).build().execute(
+    add_to_dataset_command().with_communicator(communicator).build().execute(
         urls=urls,
-        name=name,
+        dataset_name=name,
         external=external,
         force=force,
         overwrite=overwrite,
@@ -731,7 +742,7 @@ def add(name, urls, external, force, overwrite, create, sources, destination, re
         destination=destination,
         ref=ref,
     )
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("ls-files")
@@ -754,15 +765,19 @@ def add(name, urls, external, force, overwrite, create, sources, destination, re
 )
 def ls_files(names, creators, include, exclude, format, columns):
     """List files in dataset."""
-    from renku.core.commands.dataset import list_files
+    from renku.core.commands.dataset import list_files_command
+
+    if format not in DATASETS_FORMATS:
+        raise click.BadParameter(f"Format '{format}' not supported")
 
     result = (
-        list_files()
+        list_files_command()
         .lock_dataset()
         .build()
-        .execute(datasets=names, creators=creators, include=include, exclude=exclude, format=format, columns=columns)
+        .execute(datasets=names, creators=creators, include=include, exclude=exclude)
     )
-    click.echo(result.output)
+
+    click.echo(DATASET_FILES_FORMATS[format](result.output, columns=columns))
 
 
 @dataset.command()
@@ -772,21 +787,23 @@ def ls_files(names, creators, include, exclude, format, columns):
 @click.option("-y", "--yes", is_flag=True, help="Confirm unlinking of all files.")
 def unlink(name, include, exclude, yes):
     """Remove matching files from a dataset."""
-    from renku.core.commands.dataset import file_unlink
+    from renku.core.commands.dataset import file_unlink_command
 
     communicator = ClickCallback()
-    file_unlink().with_communicator(communicator).build().execute(name=name, include=include, exclude=exclude, yes=yes)
-    click.secho("OK", fg="green")
+    file_unlink_command().with_communicator(communicator).build().execute(
+        name=name, include=include, exclude=exclude, yes=yes
+    )
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("rm")
 @click.argument("name")
 def remove(name):
     """Delete a dataset."""
-    from renku.core.commands.dataset import remove_dataset
+    from renku.core.commands.dataset import remove_dataset_command
 
-    remove_dataset().build().execute(name)
-    click.secho("OK", fg="green")
+    remove_dataset_command().build().execute(name)
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("tag")
@@ -798,8 +815,8 @@ def tag(name, tag, description, force):
     """Create a tag for a dataset."""
     from renku.core.commands.dataset import add_dataset_tag_command
 
-    add_dataset_tag_command().build().execute(name=name, tag=tag, description=description, force=force)
-    click.secho("OK", fg="green")
+    add_dataset_tag_command().build().execute(dataset_name=name, tag=tag, description=description, force=force)
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("rm-tags")
@@ -809,8 +826,8 @@ def remove_tags(name, tags):
     """Remove tags from a dataset."""
     from renku.core.commands.dataset import remove_dataset_tags_command
 
-    remove_dataset_tags_command().build().execute(name=name, tags=tags)
-    click.secho("OK", fg="green")
+    remove_dataset_tags_command().build().execute(dataset_name=name, tags=tags)
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("ls-tags")
@@ -820,7 +837,7 @@ def ls_tags(name, format):
     """List all tags of a dataset."""
     from renku.core.commands.dataset import list_tags_command
 
-    result = list_tags_command().lock_dataset().build().execute(name=name, format=format)
+    result = list_tags_command().lock_dataset().build().execute(dataset_name=name, format=format)
     click.echo(result.output)
 
 
@@ -830,7 +847,7 @@ def export_provider_argument(*param_decls, **attrs):
     def wrapper(f):
         from click import argument
 
-        from renku.core.commands.providers import ProviderFactory
+        from renku.core.management.dataset.providers import ProviderFactory
 
         providers = [k.lower() for k, p in ProviderFactory.providers().items() if p.supports_export]
         f = argument("provider", type=click.Choice(providers))(f)
@@ -845,7 +862,7 @@ def export_provider_options(*param_decls, **attrs):
     def wrapper(f):
         from click_option_group import optgroup
 
-        from renku.core.commands.providers import ProviderFactory
+        from renku.core.management.dataset.providers import ProviderFactory
 
         providers = [
             (k, v) for k, v in ProviderFactory.providers().items() if v.supports_export and v.export_parameters()
@@ -879,17 +896,17 @@ def export_provider_options(*param_decls, **attrs):
 def export_(name, provider, publish, tag, **kwargs):
     """Export data to 3rd party provider."""
     from renku.core import errors
-    from renku.core.commands.dataset import export_dataset
+    from renku.core.commands.dataset import export_dataset_command
 
     try:
         communicator = ClickCallback()
-        export_dataset().lock_dataset().with_communicator(communicator).build().execute(
+        export_dataset_command().lock_dataset().with_communicator(communicator).build().execute(
             name=name, provider_name=provider, publish=publish, tag=tag, **kwargs
         )
     except (ValueError, errors.InvalidAccessToken, errors.DatasetNotFound, errors.RequestError) as e:
         raise click.BadParameter(e)
 
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("import")
@@ -902,13 +919,15 @@ def import_(uri, name, extract, yes):
 
     Supported providers: [Dataverse, Renku, Zenodo]
     """
-    from renku.core.commands.dataset import import_dataset
+    from renku.core.commands.dataset import import_dataset_command
 
     communicator = ClickCallback()
-    import_dataset().with_communicator(communicator).build().execute(uri=uri, name=name, extract=extract, yes=yes)
+    import_dataset_command().with_communicator(communicator).build().execute(
+        uri=uri, name=name, extract=extract, yes=yes
+    )
 
     click.secho(" " * 79 + "\r", nl=False)
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
 
 
 @dataset.command("update")
@@ -924,10 +943,10 @@ def import_(uri, name, extract, yes):
 @click.option("-e", "--external", is_flag=True, help="Update external data.")
 def update(names, creators, include, exclude, ref, delete, external):
     """Updates files in dataset from a remote Git repo."""
-    from renku.core.commands.dataset import update_datasets
+    from renku.core.commands.dataset import update_datasets_command
 
     communicator = ClickCallback()
-    update_datasets().with_communicator(communicator).build().execute(
+    update_datasets_command().with_communicator(communicator).build().execute(
         names=list(names),
         creators=creators,
         include=include,
@@ -936,4 +955,4 @@ def update(names, creators, include, exclude, ref, delete, external):
         delete=delete,
         external=external,
     )
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
