@@ -23,6 +23,7 @@
    :description: Check your system and repository for potential problems.
    :extended:
 """
+
 import textwrap
 
 import click
@@ -30,15 +31,24 @@ import click
 
 @click.command()
 @click.pass_context
-def doctor(ctx):
+@click.option("--fix", is_flag=True, help="Fix issues when possible.")
+def doctor(ctx, fix):
     """Check your system and repository for potential problems."""
+    import renku.cli.utils.color as color
+    from renku.cli.utils.callback import ClickCallback
     from renku.core.commands.doctor import DOCTOR_INFO, doctor_check_command
 
+    communicator = ClickCallback()
+
     click.secho("\n".join(textwrap.wrap(DOCTOR_INFO)) + "\n", bold=True)
-    is_ok, problems = doctor_check_command().build().execute().output
+
+    command = doctor_check_command(with_fix=fix)
+    if fix:
+        command = command.with_communicator(communicator)
+    is_ok, problems = command.build().execute(fix=fix).output
 
     if is_ok:
-        click.secho("Everything seems to be ok.", fg="green")
+        click.secho("Everything seems to be ok.", fg=color.GREEN)
         ctx.exit(0)
 
     click.secho(problems)
