@@ -40,8 +40,7 @@ some output file is manually modified.
 
 import click
 
-from renku.cli.utils.callback import ClickCallback
-from renku.core.commands.githooks import install_githooks_command, uninstall_githooks_command
+import renku.cli.utils.color as color
 
 
 @click.group()
@@ -53,13 +52,18 @@ def githooks():
 @click.option("--force", is_flag=True, help="Override existing hooks.")
 def install(force):
     """Install Git hooks."""
+    from renku.cli.utils.callback import ClickCallback
+    from renku.core.commands.githooks import install_githooks_command
+
     communicator = ClickCallback()
     install_githooks_command().with_communicator(communicator).build().execute(force)
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
 
 
 @githooks.command()
 def uninstall():
     """Uninstall Git hooks."""
+    from renku.core.commands.githooks import uninstall_githooks_command
+
     uninstall_githooks_command().build().execute()
-    click.secho("OK", fg="green")
+    click.secho("OK", fg=color.GREEN)
