@@ -20,17 +20,25 @@
 Removing a file that belongs to a dataset will update its metadata. It also
 will attempt to update tracking information for files stored in an external
 storage (using Git LFS).
+
+.. cheatsheet::
+   :group: Misc
+   :command: $ renku rm <path>...
+   :description: Safely delete files from a project.
+   :extended:
+
 """
 
 import click
 
 from renku.cli.utils.callback import ClickCallback
-from renku.core.commands.remove import remove_command
 
 
 @click.command(name="rm")
 @click.argument("sources", type=click.Path(exists=True), nargs=-1, required=True)
 def remove(sources):
     """Remove files and check repository for potential problems."""
+    from renku.core.commands.remove import remove_command
+
     communicator = ClickCallback()
     remove_command().with_communicator(communicator).build().execute(sources=sources, edit_command=click.edit)
