@@ -28,6 +28,16 @@ Tracking execution of your command line script is done by simply adding the
 * input files or directories if linked to existing paths in the repository,
 * output files or directories if modified or created while running the command.
 
+It will create a ``Plan`` (Workflow Template) that can be reused and a ``Run``
+which is a record of a past workflow execution for provenance purposes. Refer
+to the :ref:`cli-workflow` documentation for more details on this distinction.
+
+Basic usage is:
+
+.. code-block:: console
+
+    $ renku run --name <plan name> -- <console command>
+
 .. note:: If there were uncommitted changes in the repository, then the
    ``renku run`` command fails. See :program:`git status` for details.
 
@@ -49,6 +59,14 @@ Tracking execution of your command line script is done by simply adding the
    actually redirected. Renku specific messages such as errors get printed to
    the terminal as usual and don't get redirected.
 
+.. cheatsheet::
+   :group: Running
+   :command: $ renku run --name <name> <command> [--input <in_file>...] [--output <out_file>...]
+   :description: Execute a <command> with Renku tracking inputs and outputs. Input and output files
+                 are automatically detected from the command string. Creates a workflow template
+                 named <name>. With --input and/or --output: Manually specify input or output files to track.
+   :extended:
+
 Detecting input paths
 ~~~~~~~~~~~~~~~~~~~~~
 
@@ -73,6 +91,18 @@ if:
    the arguments that are passed on the command line. Files or directories
    specified with this option will not be passed as input arguments to the
    script.
+   You can specify ``--input name=path`` or just `--input path``, the former
+   of which would also set the name of the input on the resulting Plan.
+
+.. topic:: Specifying auxiliary parameters (``--param``)
+
+   You can specify extra parameters to your program explicitly by using the
+   ``--param`` option. This is useful for getting Renku to consider a
+   parameter as just a string even if it matches a file name in the project.
+   This option is not a replacement for the arguments that are passed on the
+   command line.
+   You can specify ``--param name=value`` or just `--param value``, the former
+   of which would also set the name of the parameter on the resulting Plan.
 
 .. topic:: Disabling input detection (``--no-input-detection``)
 
@@ -118,12 +148,20 @@ those paths. Therefore:
    You can specify the ``--no-output`` option to force tracking of such
    an execution.
 
+.. cheatsheet::
+   :group: Running
+   :command: $ renku run --name <name> <command> --no-output
+   :description: Run a <command> that produces no output.
+   :extended:
+
 .. topic:: Specifying outputs explicitly (``--output``)
 
    You can specify expected outputs of your program explicitly by using the
    ``--output`` option. These output must exist after the execution of the
    ``renku run`` command. However, they do not need to be modified by
    the command.
+   You can specify ``--output name=path`` or just `--output path``, the former
+   of which would also set the name of the output on the resulting Plan.
 
 .. topic:: Disabling output detection (``--no-output-detection``)
 
@@ -171,8 +209,8 @@ environment variable. When set, it points to a sub-directory within the
 Exit codes
 ~~~~~~~~~~
 
-All Unix commands return a number between 0 and 255 which is called
-"exit code". In case other numbers are returned, they are treaded module 256
+All Unix commands return a number between 0 and 255 which is called an
+"exit code". In case other numbers are returned, they are treated modulo 256
 (-10 is equivalent to 246, 257 is equivalent to 1). The exit-code 0 represents
 a *success* and non-zero exit-code indicates a *failure*.
 
@@ -208,7 +246,6 @@ import click
 
 from renku.cli.utils.callback import ClickCallback
 from renku.core.commands.options import option_isolation
-from renku.core.commands.run import run_command
 
 
 @click.command(context_settings=dict(ignore_unknown_options=True))
@@ -217,6 +254,7 @@ from renku.core.commands.run import run_command
 @click.option("--keyword", multiple=True, help="List of keywords for the workflow.")
 @click.option("explicit_inputs", "--input", multiple=True, help="Force a path to be considered as an input.")
 @click.option("explicit_outputs", "--output", multiple=True, help="Force a path to be considered an output.")
+@click.option("explicit_parameters", "--param", multiple=True, help="Force a string to be considered a parameter.")
 @click.option("--no-output", is_flag=True, default=False, help="Allow command without output files.")
 @click.option("--no-input-detection", is_flag=True, default=False, help="Disable auto-detection of inputs.")
 @click.option("--no-output-detection", is_flag=True, default=False, help="Disable auto-detection of outputs.")
@@ -236,6 +274,7 @@ def run(
     keyword,
     explicit_inputs,
     explicit_outputs,
+    explicit_parameters,
     no_output,
     no_input_detection,
     no_output_detection,
@@ -244,6 +283,8 @@ def run(
     command_line,
 ):
     """Tracking work on a specific problem."""
+    from renku.core.commands.run import run_command
+
     communicator = ClickCallback()
     command = run_command()
 
@@ -256,6 +297,7 @@ def run(
         keyword=keyword,
         explicit_inputs=explicit_inputs,
         explicit_outputs=explicit_outputs,
+        explicit_parameters=explicit_parameters,
         no_output=no_output,
         no_input_detection=no_input_detection,
         no_output_detection=no_output_detection,
