@@ -17,15 +17,21 @@
 # limitations under the License.
 r"""Update outdated files created by the "run" command.
 
+.. image:: ../_static/asciicasts/update.delay.gif
+   :width: 850
+   :alt: Update outdate files
+
 Recreating outdated files
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-The information about dependencies for each file in the repository is generated
-from information stored in the underlying Git repository.
+The information about dependencies for each file in a Renku project is stored
+in various metadata.
 
-A minimal dependency graph is generated for each outdated file stored in the
-repository. It means that only the necessary steps will be executed and the
-workflow used to orchestrate these steps is stored in the repository.
+When an update command is executed, Renku looks into the most recent execution
+of each workflow (Run and Plan combination) and checks which one is outdated
+(i.e. at least one of its inputs is modified). It generates a minimal
+dependency graph for each outdated file stored in the repository. It means
+that only the necessary steps will be executed.
 
 Assume that the following history for the file ``H`` exists.
 
@@ -47,23 +53,37 @@ The first example shows situation when ``D`` is modified and files ``E`` and
     ** - modified
     () - needs update
 
-In this situation, you can do effectively two things:
+In this situation, you can do effectively three things:
 
-* Recreate a single file by running
-
-  .. code-block:: console
-
-     $ renku update E
-
-* Update all files by simply running
+* Update all files
 
   .. code-block:: console
 
      $ renku update --all
 
+* Update only ``E``
+
+  .. code-block:: console
+
+     $ renku update E
+
+* Update ``E`` and ``H``
+
+  .. code-block:: console
+
+     $ renku update H
+
 .. note:: If there were uncommitted changes then the command fails.
    Check :program:`git status` to see details.
 
+.. cheatsheet::
+   :group: Running
+   :command: $ renku update [--all] [<path>...]
+   :description: Update outdated output files created by renku run. With
+                 <path>'s: Only recreate these files. With --all: Update
+                 all outdated output files.
+   :extended:
+
 Pre-update checks
 ~~~~~~~~~~~~~~~~~
 
@@ -85,7 +105,7 @@ file (e.g. ``renku update G``). See also :ref:`cli-status`.
 Update siblings
 ~~~~~~~~~~~~~~~
 
-If a tool produces multiple output files, these outputs need to be always
+If a workflow step produces multiple output files, these outputs will be always
 updated together.
 
 .. code-block:: text
@@ -96,44 +116,58 @@ updated together.
                   \
                    (D)
 
-An attempt to update a single file would fail with the following error.
-
-.. code-block:: console
-
-   $ renku update C
-   Error: There are missing output siblings:
-
-        B
-        D
-
-   Include the files above in the command or use --with-siblings option.
+An attempt to update a single file would update its siblings as well.
 
 The following commands will produce the same result.
 
 .. code-block:: console
 
-   $ renku update --with-siblings C
+   $ renku update C
    $ renku update B C D
 
 """
 
 import click
+from lazy_object_proxy import Proxy
 
 from renku.cli.utils.callback import ClickCallback
-from renku.core.commands.options import option_siblings
-from renku.core.commands.update import update_workflows
+from renku.cli.utils.plugins import available_workflow_providers
+from renku.core import errors
 
 
 @click.command()
-@click.option("--revision", default="HEAD")
-@click.option("--no-output", is_flag=True, default=False, help="Display commands without output files.")
 @click.option("--all", "-a", "update_all", is_flag=True, default=False, help="Update all outdated files.")
-@option_siblings
+@click.option("--dry-run", "-n", is_flag=True, default=False, help="Show a preview of plans that will be executed.")
 @click.argument("paths", type=click.Path(exists=True, dir_okay=True), nargs=-1)
-def update(revision, no_output, update_all, siblings, paths):
+@click.option(
+    "provider",
+    "-p",
+    "--provider",
+    default="cwltool",
+    show_default=True,
+    type=click.Choice(Proxy(available_workflow_providers), case_sensitive=False),
+    help="The workflow engine to use.",
+)
+@click.option(
+    "config", "-c", "--config", metavar="<config file>", help="YAML file containing configuration for the provider."
+)
+def update(update_all, dry_run, paths, provider, config):
     """Update existing files by rerunning their outdated workflow."""
+    from renku.core.commands.format.activity import tabulate_activities
+    from renku.core.commands.update import update_command
+
     communicator = ClickCallback()
 
-    update_workflows().with_communicator(communicator).build().execute(
-        revision=revision, no_output=no_output, update_all=update_all, siblings=siblings, paths=paths
-    )
+    try:
+        result = (
+            update_command()
+            .with_communicator(communicator)
+            .build()
+            .execute(update_all=update_all, dry_run=dry_run, paths=paths, provider=provider, config=config)
+        )
+    except errors.NothingToExecuteError:
+        exit(1)
+    else:
+        if dry_run:
+            activities, modified_inputs = result.output
+            click.echo(tabulate_activities(activities, modified_inputs))
