@@ -37,7 +37,7 @@ class DatasetsProvenance:
     @property
     def datasets(self) -> List[Dataset]:
         """Return an iterator of datasets."""
-        return self.dataset_gateway.get_all_datasets()
+        return self.dataset_gateway.get_all_active_datasets()
 
     def get_by_id(self, id: str, immutable: bool = False) -> Optional[Dataset]:
         """Return a dataset by its id."""
@@ -52,25 +52,27 @@ class DatasetsProvenance:
 
             return dataset.copy()
 
-    def get_by_name(self, name: str, immutable: bool = False) -> Optional[Dataset]:
+    def get_by_name(self, name: str, immutable: bool = False, strict: bool = False) -> Optional[Dataset]:
         """Return a dataset by its name."""
         dataset = self.dataset_gateway.get_by_name(name)
         if not dataset:
+            if strict:
+                raise errors.DatasetNotFound(name=name)
+
             return
         if not dataset.immutable or immutable:
             return dataset
 
         return dataset.copy()
 
-    def get_provenance(self):
+    def get_provenance_tails(self):
         """Return the provenance for all datasets."""
-        return self.dataset_gateway.get_provenance()
+        return self.dataset_gateway.get_provenance_tails()
 
     def get_previous_version(self, dataset: Dataset) -> Optional[Dataset]:
         """Return the previous version of a dataset if any."""
-        if not dataset.derived_from:
-            return
-        return self.get_by_id(dataset.derived_from.url_id)
+        if dataset.is_derivation():
+            return self.get_by_id(dataset.derived_from.url_id)
 
     def add_or_update(self, dataset: Dataset, date: datetime = None, creator: Person = None):
         """Add/update a dataset according to its new content.
