@@ -17,7 +17,6 @@
 # limitations under the License.
 """Git utilities."""
 
-import configparser
 import os
 import re
 from pathlib import Path
@@ -26,9 +25,9 @@ from urllib.parse import urlparse
 import attr
 
 from renku.core import errors
-from renku.core.utils.scm import is_ascii
+from renku.core.utils.os import is_ascii, normalize_to_ascii
 
-_RE_PROTOCOL = r"(?P<protocol>(git\+)?(https?|git|ssh|rsync))\://"
+_RE_SCHEME = r"(?P<scheme>(git\+)?(https?|git|ssh|rsync))\://"
 
 _RE_USERNAME = r"(?:(?P<username>.+)@)?"
 
@@ -44,14 +43,14 @@ _RE_HOSTNAME = (
 
 _RE_PORT = r":(?P<port>\d+)"
 
-_RE_PATHNAME = r"(?P<pathname>(([\w\-\~\.]+)/)*?(((?P<owner>([\w\-\.]+/?)+)/)?(?P<name>[\w\-\.]+)(\.git)?)?)/*"
+_RE_PATHNAME = r"(?P<path>(([\w\-\~\.]+)/)*?(((?P<owner>([\w\-\.]+/?)+)/)?(?P<name>[\w\-\.]+)(\.git)?)?)/*"
 
 _RE_PATHNAME_WITH_GITLAB = (
-    r"(?P<pathname>((((gitlab/){0,1}|([\w\-\~\.]+/)*?)(?P<owner>([\w\-\.]+/)*[\w\-\.]+)/)?"
+    r"(?P<path>((((gitlab/){0,1}|([\w\-\~\.]+/)*?)(?P<owner>([\w\-\.]+/)*[\w\-\.]+)/)?"
     r"(?P<name>[\w\-\.]+)(\.git)?)?)/*"
 )
 
-_RE_UNIXPATH = r"(file\://)?(?P<pathname>\/$|((?=\/)|\.|\.\.)(\/(?=[^/\0])[^/\0]+)*\/?)"
+_RE_UNIXPATH = r"(file\://)?(?P<path>\/$|((?=\/)|\.|\.\.)(\/(?=[^/\0])[^/\0]+)*\/?)"
 
 
 def _build(*parts):
@@ -62,9 +61,9 @@ def _build(*parts):
 #: Define possible repository URLs.
 _REPOSITORY_URLS = (
     # https://user:pass@example.com/owner/repo.git
-    _build(_RE_PROTOCOL, _RE_USERNAME_PASSWORD, _RE_HOSTNAME, r"/", _RE_PATHNAME_WITH_GITLAB),
+    _build(_RE_SCHEME, _RE_USERNAME_PASSWORD, _RE_HOSTNAME, r"/", _RE_PATHNAME_WITH_GITLAB),
     # https://user:pass@example.com:gitlab/owner/repo.git
-    _build(_RE_PROTOCOL, _RE_USERNAME_PASSWORD, _RE_HOSTNAME, _RE_PORT, r"/", _RE_PATHNAME_WITH_GITLAB),
+    _build(_RE_SCHEME, _RE_USERNAME_PASSWORD, _RE_HOSTNAME, _RE_PORT, r"/", _RE_PATHNAME_WITH_GITLAB),
     # git@example.com:owner/repo.git
     _build(_RE_USERNAME, _RE_HOSTNAME, r":", _RE_PATHNAME_WITH_GITLAB),
     # /path/to/repo
@@ -85,30 +84,26 @@ class GitURL(object):
 
     # Initial value
     href = attr.ib()
-    # Parsed protocols
-    pathname = attr.ib(default=None)
-    protocols = attr.ib(default=attr.Factory(list), init=False)
-    protocol = attr.ib(default="ssh")
+    path = attr.ib(default=None)
+    scheme = attr.ib(default="ssh")
     hostname = attr.ib(default="localhost")
     username = attr.ib(default=None)
     password = attr.ib(default=None)
     port = attr.ib(default=None)
     owner = attr.ib(default=None)
     name = attr.ib(default=None, converter=filter_repo_name)
+    slug = attr.ib(default=None)
     _regex = attr.ib(default=None, eq=False, order=False)
 
     def __attrs_post_init__(self):
         """Derive basic information."""
-        if self.protocol:
-            protocols = self.protocol.split("+")
-            self.protocols = protocols
-            self.protocol = protocols[-1]
+        if not self.name and self.path:
+            self.name = filter_repo_name(Path(self.path).name)
 
-        if not self.name and self.pathname:
-            self.name = filter_repo_name(Path(self.pathname).name)
+        self.slug = normalize_to_ascii(self.name)
 
     @classmethod
-    def parse(cls, href):
+    def parse(cls, href) -> "GitURL":
         """Derive URI components."""
         if not is_ascii(href):
             raise UnicodeError(f"`{href}` is not a valid Git remote")
@@ -121,7 +116,7 @@ class GitURL(object):
             # NOTE: use known gitlab url to simplify regex to make detection more robust
             gitlab_url = urlparse(gitlab_url)
             gitlab_re = _build(
-                _RE_PROTOCOL,
+                _RE_SCHEME,
                 _RE_USERNAME_PASSWORD,
                 r"(?P<hostname>" + re.escape(gitlab_url.hostname) + ")",
                 r":(?P<port>" + str(gitlab_url.port) + ")" if gitlab_url.port else "",
@@ -136,7 +131,17 @@ class GitURL(object):
             if matches:
                 return cls(href=href, regex=regex, **matches.groupdict())
         else:
-            raise errors.ConfigurationError(f"`{href}` is not a valid Git remote")
+            raise errors.InvalidGitURL(f"`{href}` is not a valid Git URL")
+
+    @property
+    def instance_url(self):
+        """Get the url of the git instance."""
+        url = urlparse(self.href)
+
+        path = self.path.split(self.owner, 1)[0]
+        url = url._replace(path=path)
+
+        return url.geturl()
 
     @property
     def image(self):
@@ -147,53 +152,3 @@ class GitURL(object):
         if self.name:
             img += "/" + self.name
         return img
-
-
-@attr.s
-class Range:
-    """Represent parsed Git revision as an interval."""
-
-    start = attr.ib()
-    stop = attr.ib()
-
-    @classmethod
-    def rev_parse(cls, git, revision):
-        """Parse revision string."""
-        start, is_range, stop = revision.partition("..")
-        if not is_range:
-            start, stop = None, start
-        elif not stop:
-            stop = "HEAD"
-
-        return cls(start=git.rev_parse(start) if start else None, stop=git.rev_parse(stop))
-
-    def __str__(self):
-        """Format range."""
-        if self.start:
-            return "{self.start}..{self.stop}".format(self=self)
-        return str(self.stop)
-
-
-def get_user_info(git):
-    """Get Git repository's owner name and email."""
-
-    git_config = git.config_reader()
-    try:
-        name = git_config.get_value("user", "name", None)
-        email = git_config.get_value("user", "email", None)
-    except (configparser.NoOptionError, configparser.NoSectionError):  # pragma: no cover
-        raise errors.ConfigurationError(
-            "The user name and email are not configured. "
-            'Please use the "git config" command to configure them.\n\n'
-            '\tgit config --global --add user.name "John Doe"\n'
-            "\tgit config --global --add user.email "
-            '"john.doe@example.com"\n'
-        )
-
-    # Check the git configuration.
-    if not name:  # pragma: no cover
-        raise errors.MissingUsername()
-    if not email:  # pragma: no cover
-        raise errors.MissingEmail()
-
-    return name, email
