@@ -17,4 +17,17 @@
 # limitations under the License.
 """Renku plugin implementations."""
 
+from renku.core.management.workflow.converters.cwl import CWLExporter
+from renku.core.management.workflow.providers.cwltool import CWLToolProvider
+
 __all__ = []
+
+workflow_exporters = [CWLExporter]
+workflow_providers = [CWLToolProvider]
+
+try:
+    from renku.core.management.workflow.providers.toil import ToilProvider
+
+    workflow_providers.append(ToilProvider)
+except ImportError:
+    pass
