@@ -17,13 +17,16 @@
 # limitations under the License.
 """OS utility functions."""
 
+import hashlib
 import os
 import re
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import Generator, List, Optional, Union
 
 from renku.core import errors
 
+BLOCK_SIZE = 4096
+
 
 def get_relative_path_to_cwd(path: Union[Path, str]) -> str:
     """Get a relative path to current working directory."""
@@ -31,12 +34,37 @@ def get_relative_path_to_cwd(path: Union[Path, str]) -> str:
     return os.path.relpath(absolute_path, os.getcwd())
 
 
-def get_relative_path(path: Union[Path, str], base: Union[Path, str]) -> Optional[Path]:
+def get_absolute_path(path: Union[Path, str], base: Union[Path, str] = None) -> str:
+    """Return absolute normalized path without resolving symlinks."""
+    if base is not None:
+        base = Path(base).resolve()
+        path = os.path.join(base, path)
+
+    # NOTE: Do not use os.path.realpath or Path.resolve() because they resolve symlinks
+    return os.path.abspath(path)
+
+
+def get_safe_relative_path(path: Union[Path, str], base: Union[Path, str]) -> Path:
+    """Return a relative path to the base and check path is within base with all symlinks resolved.
+
+    NOTE: This is used to prevent path traversal attack.
+    """
+    try:
+        base = Path(base).resolve()
+        absolute_path = base / path
+        return absolute_path.resolve().relative_to(base)
+    except ValueError:
+        raise ValueError(f"Path '{path}' is not with base directory '{base}'")
+
+
+def get_relative_path(path: Union[Path, str], base: Union[Path, str], strict: bool = False) -> Optional[Path]:
     """Return a relative path to the base if path is within base without resolving symlinks."""
     try:
         absolute_path = get_absolute_path(path=path, base=base)
         return Path(absolute_path).relative_to(base)
     except ValueError:
+        if strict:
+            raise errors.ParameterError("File {} is not within path {}".format(path, base))
         return
 
 
@@ -59,6 +87,16 @@ def get_relative_paths(base: Union[Path, str], paths: List[Union[Path, str]]) ->
     return relative_paths
 
 
+def get_files(path: Path) -> Generator[Path, None, None]:
+    """Return all files from a starting file/directory."""
+    if not path.is_dir():
+        yield path
+    else:
+        for subpath in path.rglob("*"):
+            if not subpath.is_dir():
+                yield subpath
+
+
 def are_paths_related(a, b) -> bool:
     """Return True if paths are equal or one is the parent of the other."""
     common_path = os.path.commonpath((a, b))
@@ -66,13 +104,13 @@ def are_paths_related(a, b) -> bool:
     return absolute_common_path == os.path.abspath(a) or absolute_common_path == os.path.abspath(b)
 
 
-def get_absolute_path(path: Union[Path, str], base: Union[Path, str] = None) -> str:
-    """Return absolute normalized path without resolving symlinks."""
-    if base is not None:
-        path = os.path.join(base, path)
+def is_path_empty(path: Union[Path, str]) -> bool:
+    """Check if path contains files.
 
-    # NOTE: Do not use os.path.realpath or Path.resolve() because they resolve symlinks
-    return os.path.abspath(path)
+    :ref path: target path
+    """
+    subpaths = Path(path).rglob("*")
+    return not any(subpaths)
 
 
 def print_markdown(text: str):
@@ -107,10 +145,55 @@ def normalize_to_ascii(input_string, sep="-"):
     )
 
 
-def delete_file(path: Union[Path, str], ignore_errors: bool = True):
-    """Delete a file."""
+def delete_file(filepath: Union[Path, str], ignore_errors: bool = True, follow_symlinks: bool = False):
+    """Remove a file/symlink and its pointer file (for external files)."""
+    path = Path(filepath)
+    link = None
     try:
-        os.unlink(path)
+        link = path.parent / os.readlink(path)
+    except FileNotFoundError:
+        if not ignore_errors:
+            raise
+        return
+    except OSError:  # not a symlink but a normal file
+        pass
+
+    try:
+        os.remove(path)
     except OSError:
         if not ignore_errors:
             raise
+
+    if follow_symlinks and link:
+        try:
+            os.remove(link)
+        except FileNotFoundError:
+            pass
+
+
+def hash_file(path: Union[Path, str]) -> Optional[str]:
+    """Calculate the sha256 hash of a file."""
+    if not os.path.exists(path):
+        return
+
+    sha256_hash = hashlib.sha256()
+
+    with open(path, "rb") as f:
+        for byte_block in iter(lambda: f.read(BLOCK_SIZE), b""):
+            sha256_hash.update(byte_block)
+
+    return sha256_hash.hexdigest()
+
+
+def hash_str(content: str):
+    """Calculate the sha256 hash of a string."""
+    sha256_hash = hashlib.sha256()
+
+    content_bytes = content.encode("utf-8")
+
+    blocks = (len(content_bytes) - 1) // BLOCK_SIZE + 1
+    for i in range(blocks):
+        byte_block = content_bytes[i * BLOCK_SIZE : (i + 1) * BLOCK_SIZE]
+        sha256_hash.update(byte_block)
+
+    return sha256_hash.hexdigest()
