@@ -23,17 +23,17 @@ from functools import wraps
 from pathlib import Path
 
 import portalocker
-from git import GitCommandError, Repo
 
+from renku.core import errors
 from renku.core.errors import RenkuException, UninitializedProject
-from renku.core.management.config import RENKU_HOME
-from renku.core.management.repository import RepositoryApiMixin
+from renku.core.management import RENKU_HOME
+from renku.core.metadata.repository import Repository
 from renku.core.utils.contexts import click_context
 from renku.service.cache.config import REDIS_NAMESPACE
 from renku.service.cache.models.job import Job
 from renku.service.cache.models.project import Project
 from renku.service.cache.models.user import User
-from renku.service.config import PROJECT_CLONE_NO_DEPTH
+from renku.service.config import PROJECT_CLONE_DEPTH_DEFAULT, PROJECT_CLONE_NO_DEPTH
 from renku.service.controllers.utils.remote_project import RemoteProject
 from renku.service.errors import (
     AuthenticationTokenMissing,
@@ -71,18 +71,26 @@ class RenkuOperationMixin(metaclass=ABCMeta):
 
     JOB_RESPONSE_SERIALIZER = DelayedResponseRPC()
 
-    def __init__(self, cache, user_data, request_data, migrate_project=False, skip_lock=False):
+    def __init__(
+        self,
+        cache,
+        user_data,
+        request_data,
+        migrate_project=False,
+        skip_lock=False,
+        clone_depth=PROJECT_CLONE_DEPTH_DEFAULT,
+    ):
         """Read operation mixin for controllers."""
         if user_data and "user_id" in user_data and cache is not None:
             self.user = cache.ensure_user(user_data)
 
         self.is_write = False
+        self.migrate_project = migrate_project
         self.skip_lock = skip_lock
-
+        self.clone_depth = clone_depth
         self.cache = cache
         self.user_data = user_data
         self.request_data = request_data
-        self.migrate_project = migrate_project
 
         # NOTE: Manually set `migrate_project` flag takes higher precedence
         # than `migrate_project` flag from the request. Reason for this is
@@ -138,7 +146,7 @@ class RenkuOperationMixin(metaclass=ABCMeta):
 
             job = self.cache.make_job(self.user, job_data={"ctrl_context": {**self.context, **ctrl_cls}})
 
-            with enqueue_retry(f"{REDIS_NAMESPACE}delayed.ctrl.{ctrl_cls['renku_ctrl']}") as queue:
+            with enqueue_retry(f"{REDIS_NAMESPACE}.delayed.ctrl.{ctrl_cls['renku_ctrl']}") as queue:
                 queue.enqueue(delayed_ctrl_job, self.context, self.user_data, job.job_id, **ctrl_cls)
 
             return job
@@ -171,6 +179,8 @@ class RenkuOperationMixin(metaclass=ABCMeta):
                 # only to be executed from delayed tasks.
                 if self.migrate_project:
                     clone_context["depth"] = PROJECT_CLONE_NO_DEPTH
+                elif self.clone_depth:
+                    clone_context["depth"] = self.clone_depth
 
                 project = ProjectCloneCtrl(self.cache, self.user_data, clone_context).project_clone()
 
@@ -180,35 +190,36 @@ class RenkuOperationMixin(metaclass=ABCMeta):
                 ref = self.request_data.get("ref", None)
 
                 if ref:
-                    repo = Repo(project.abs_path)
-                    if ref != repo.active_branch.name:
+                    repository = Repository(project.abs_path)
+                    if ref != repository.active_branch.name:
                         # NOTE: Command called for different branch than the one used in cache, change branch
-                        if not repo.remotes or len(repo.remotes) != 1:
+                        if len(repository.remotes) != 1:
                             raise RenkuException("Couldn't find remote for project in cache.")
-                        origin = repo.remotes[0]
+                        origin = repository.remotes[0]
                         remote_branch = f"{origin}/{ref}"
 
                         with project.write_lock():
                             # NOTE: Add new ref to remote branches
-                            repo.git.remote("set-branches", "--add", origin, ref)
-                            if self.migrate_project:
-                                repo.git.fetch(origin, ref)
+                            repository.run_git_command("remote", "set-branches", "--add", origin, ref)
+                            if self.migrate_project or self.clone_depth == PROJECT_CLONE_NO_DEPTH:
+                                repository.fetch(origin, ref)
                             else:
-                                repo.git.fetch("--depth=1", origin, ref)
+                                repository.fetch(origin, ref, depth=self.clone_depth)
 
                             # NOTE: Switch to new ref
-                            repo.git.checkout("--track", "-f", "-b", ref, remote_branch)
+                            repository.run_git_command("checkout", "--track", "-f", "-b", ref, remote_branch)
 
                             # NOTE: cleanup remote branches in case a remote was deleted (fetch fails otherwise)
-                            repo.git.remote("prune", origin)
+                            repository.run_git_command("remote", "prune", origin)
 
-                            for branch in repo.refs:
-                                if branch.tracking_branch() and not branch.tracking_branch().is_valid():
-                                    repo.git.branch("-D", branch)
+                            for branch in repository.branches:
+                                if branch.remote_branch and not branch.remote_branch.is_valid():
+                                    repository.branches.remove(branch, force=True)
                                     # NOTE: Remove left-over refspec
                                     try:
-                                        repo.git.config("--unset", f"remote.{origin}.fetch", f"origin.{branch}$")
-                                    except GitCommandError:
+                                        with repository.get_configuration(writable=True) as config:
+                                            config.remove_value(f"remote.{origin}.fetch", f"origin.{branch}$")
+                                    except errors.GitConfigurationError:
                                         pass
                 else:
                     self.reset_local_repo(project)
@@ -222,8 +233,11 @@ class RenkuOperationMixin(metaclass=ABCMeta):
     def reset_local_repo(self, project):
         """Reset the local repo to be up to date with the remote."""
 
-        # NOTE: Only do a fetch every >30s to get eventual consistency but not slow things down too much
-        if project.fetch_age < PROJECT_FETCH_TIME:
+        from renku.service.controllers.cache_migrate_project import MigrateProjectCtrl
+
+        # NOTE: Only do a fetch every >30s to get eventual consistency but not slow things down too much,
+        # except for MigrateProject since that is likely to require to unshallow the repository
+        if project.fetch_age < PROJECT_FETCH_TIME and not isinstance(self, MigrateProjectCtrl):
             return
 
         lock = project.write_lock()
@@ -236,27 +250,28 @@ class RenkuOperationMixin(metaclass=ABCMeta):
                     # NOTE: return immediately in case of multiple writers waiting
                     return
 
-                repo = Repo(project.abs_path)
+                repository = Repository(project.abs_path)
                 origin = None
-                tracking_branch = repo.active_branch.tracking_branch()
+                tracking_branch = repository.active_branch.remote_branch
                 if tracking_branch:
-                    origin = repo.remotes[tracking_branch.remote_name]
-                elif repo.remotes and len(repo.remotes) == 1:
-                    origin = repo.remotes[0]
+                    origin = tracking_branch.remote
+                elif len(repository.remotes) == 1:
+                    origin = repository.remotes[0]
 
-                if origin and not self.migrate_project:
-                    origin.fetch(repo.active_branch)
-                    repo.git.reset("--hard", f"{origin}/{repo.active_branch.name}")
+                if origin:
+                    unshallow = self.migrate_project or self.clone_depth == PROJECT_CLONE_NO_DEPTH
+                    if unshallow:
+                        try:
+                            # NOTE: It could happen that repository is already un-shallowed,
+                            # in this case we don't want to leak git exception, but still want to fetch.
+                            repository.fetch("origin", repository.active_branch, unshallow=True)
+                        except errors.GitCommandError:
+                            repository.fetch("origin", repository.active_branch)
 
-                elif origin and self.migrate_project:
-                    try:
-                        # NOTE: It could happen that repository is already un-shallowed,
-                        # in this case we don't want to leak git exception, but still want to fetch.
-                        origin.fetch(repo.active_branch, unshallow=True)
-                    except GitCommandError:
-                        origin.fetch(repo.active_branch)
-
-                    repo.git.reset("--hard", f"{origin}/{repo.active_branch}")
+                        repository.reset(f"{origin}/{repository.active_branch}", hard=True)
+                    else:
+                        repository.fetch("origin", repository.active_branch)
+                        repository.reset(f"{origin}/{repository.active_branch}", hard=True)
 
                 project.last_fetched_at = datetime.utcnow()
                 project.save()
@@ -306,7 +321,7 @@ class RenkuOperationMixin(metaclass=ABCMeta):
         with project.remote() as path:
             self.project_path = Path(path)
 
-            if not (self.project_path / RENKU_HOME / RepositoryApiMixin.METADATA).exists():
+            if not (self.project_path / RENKU_HOME).exists():
                 raise UninitializedProject(self.project_path)
 
             return self.renku_op()
@@ -321,14 +336,12 @@ class RenkuOpSyncMixin(RenkuOperationMixin, metaclass=ABCMeta):
 
     def sync(self, remote="origin"):
         """Sync with remote."""
-        from renku.core.commands.save import repo_sync
+        from renku.core.utils.git import push_changes
 
         if self.project_path is None:
             raise RenkuException("unable to sync with remote since no operation has been executed")
 
-        _, remote_branch = repo_sync(Repo(self.project_path), remote=remote)
-
-        return remote_branch
+        return push_changes(Repository(self.project_path), remote=remote)
 
     def execute_and_sync(self, remote="origin"):
         """Execute operation which controller implements and sync with the remote."""
