@@ -37,7 +37,7 @@ def user_project_clone(cache, user_data, project_data):
             .build()
             .execute(
                 project_data["url_with_auth"],
-                project.abs_path,
+                path=project.abs_path,
                 depth=project_data["depth"],
                 raise_git_except=True,
                 config={
@@ -45,7 +45,7 @@ def user_project_clone(cache, user_data, project_data):
                     "user.email": project_data["email"],
                     "pull.rebase": False,
                 },
-                checkout_rev=project_data["ref"],
+                checkout_revision=project_data["ref"],
             )
         ).output
         project.save()
