@@ -16,9 +16,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Renku service utility functions."""
-from git import Repo
 
-from renku.core.commands.save import repo_sync
+from renku.core.utils.git import push_changes
 from renku.service.config import CACHE_PROJECTS_PATH, CACHE_UPLOADS_PATH
 
 
@@ -28,7 +27,7 @@ def make_project_path(user, project):
     valid_project = project and "owner" in project and "name" in project and "project_id" in project
 
     if valid_user and valid_project:
-        return CACHE_PROJECTS_PATH / user["user_id"] / project["project_id"] / project["owner"] / project["name"]
+        return CACHE_PROJECTS_PATH / user["user_id"] / project["project_id"] / project["owner"] / project["slug"]
 
 
 def make_file_path(user, cached_file):
@@ -51,7 +50,9 @@ def valid_file(user, cached_file):
 
 def new_repo_push(repo_path, source_url, source_name="origin", source_branch="master"):
     """Push a new repo to origin."""
-    repo = Repo(repo_path)
-    repo.create_remote(source_name, source_url)
-    _, branch = repo_sync(repo, remote=source_name)
+    from renku.core.metadata.repository import Repository
+
+    repository = Repository(repo_path)
+    repository.remotes.add(source_name, source_url)
+    branch = push_changes(repository, remote=source_name)
     return branch == source_branch
